// Copyright 2017 The Bazel Authors. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.devtools.build.lib.repository;

import com.google.devtools.build.lib.cmdline.LabelConstants;
import com.google.devtools.build.lib.packages.BuildFileContainsErrorsException;

/** Exception thrown when a rule cannot be found. */
public final class ExternalRuleNotFoundException extends ExternalPackageException {
  public ExternalRuleNotFoundException(String ruleName) {
    super(
        new BuildFileContainsErrorsException(
            LabelConstants.EXTERNAL_PACKAGE_IDENTIFIER,
            "The rule named '" + ruleName + "' could not be resolved"),
        Transience.PERSISTENT);
  }
}